# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/host_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import instance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2
from yandex.cloud.compute.v1 import host_group_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/compute/v1/host_group_service.proto',
  package='yandex.cloud.compute.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0yandex/cloud/compute/v1/host_group_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/compute/v1/instance.proto\x1a(yandex/cloud/compute/v1/host_group.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\":\n\x13GetHostGroupRequest\x12#\n\rhost_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x92\x01\n\x15ListHostGroupsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"j\n\x16ListHostGroupsResponse\x12\x37\n\x0bhost_groups\x18\x01 \x03(\x0b\x32\".yandex.cloud.compute.v1.HostGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x95\x04\n\x16\x43reateHostGroupRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x94\x01\n\x06labels\x18\x04 \x03(\x0b\x32;.yandex.cloud.compute.v1.CreateHostGroupRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x1d\n\x07zone_id\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x07type_id\x18\x06 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x46\n\x12maintenance_policy\x18\x07 \x01(\x0e\x32*.yandex.cloud.compute.v1.MaintenancePolicy\x12:\n\x0cscale_policy\x18\x08 \x01(\x0b\x32$.yandex.cloud.compute.v1.ScalePolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"0\n\x17\x43reateHostGroupMetadata\x12\x15\n\rhost_group_id\x18\x01 \x01(\t\"\x8c\x04\n\x16UpdateHostGroupRequest\x12#\n\rhost_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x94\x01\n\x06labels\x18\x05 \x03(\x0b\x32;.yandex.cloud.compute.v1.UpdateHostGroupRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x46\n\x12maintenance_policy\x18\x06 \x01(\x0e\x32*.yandex.cloud.compute.v1.MaintenancePolicy\x12:\n\x0cscale_policy\x18\x07 \x01(\x0b\x32$.yandex.cloud.compute.v1.ScalePolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"0\n\x17UpdateHostGroupMetadata\x12\x15\n\rhost_group_id\x18\x01 \x01(\t\"=\n\x16\x44\x65leteHostGroupRequest\x12#\n\rhost_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"0\n\x17\x44\x65leteHostGroupMetadata\x12\x15\n\rhost_group_id\x18\x01 \x01(\t\"\x9e\x01\n\x1dListHostGroupInstancesRequest\x12#\n\rhost_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"o\n\x1eListHostGroupInstancesResponse\x12\x34\n\tinstances\x18\x01 \x03(\x0b\x32!.yandex.cloud.compute.v1.Instance\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"~\n\x19ListHostGroupHostsRequest\x12#\n\rhost_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"c\n\x1aListHostGroupHostsResponse\x12,\n\x05hosts\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.compute.v1.Host\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x83\x01\n\x1eListHostGroupOperationsRequest\x12#\n\rhost_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"q\n\x1fListHostGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xf8\n\n\x10HostGroupService\x12\x87\x01\n\x03Get\x12,.yandex.cloud.compute.v1.GetHostGroupRequest\x1a\".yandex.cloud.compute.v1.HostGroup\".\x82\xd3\xe4\x93\x02(\x12&/compute/v1/hostGroups/{host_group_id}\x12\x87\x01\n\x04List\x12..yandex.cloud.compute.v1.ListHostGroupsRequest\x1a/.yandex.cloud.compute.v1.ListHostGroupsResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/compute/v1/hostGroups\x12\xa7\x01\n\x06\x43reate\x12/.yandex.cloud.compute.v1.CreateHostGroupRequest\x1a!.yandex.cloud.operation.Operation\"I\x82\xd3\xe4\x93\x02\x1b\"\x16/compute/v1/hostGroups:\x01*\xb2\xd2*$\n\x17\x43reateHostGroupMetadata\x12\tHostGroup\x12\xb7\x01\n\x06Update\x12/.yandex.cloud.compute.v1.UpdateHostGroupRequest\x1a!.yandex.cloud.operation.Operation\"Y\x82\xd3\xe4\x93\x02+2&/compute/v1/hostGroups/{host_group_id}:\x01*\xb2\xd2*$\n\x17UpdateHostGroupMetadata\x12\tHostGroup\x12\xc0\x01\n\x06\x44\x65lete\x12/.yandex.cloud.compute.v1.DeleteHostGroupRequest\x1a!.yandex.cloud.operation.Operation\"b\x82\xd3\xe4\x93\x02(*&/compute/v1/hostGroups/{host_group_id}\xb2\xd2*0\n\x17\x44\x65leteHostGroupMetadata\x12\x15google.protobuf.Empty\x12\xbe\x01\n\x0eListOperations\x12\x37.yandex.cloud.compute.v1.ListHostGroupOperationsRequest\x1a\x38.yandex.cloud.compute.v1.ListHostGroupOperationsResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/compute/v1/hostGroups/{host_group_id}/operations\x12\xba\x01\n\rListInstances\x12\x36.yandex.cloud.compute.v1.ListHostGroupInstancesRequest\x1a\x37.yandex.cloud.compute.v1.ListHostGroupInstancesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/compute/v1/hostGroups/{host_group_id}/instances\x12\xaa\x01\n\tListHosts\x12\x32.yandex.cloud.compute.v1.ListHostGroupHostsRequest\x1a\x33.yandex.cloud.compute.v1.ListHostGroupHostsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/compute/v1/hostGroups/{host_group_id}/hostsBb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2.DESCRIPTOR,yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETHOSTGROUPREQUEST = _descriptor.Descriptor(
  name='GetHostGroupRequest',
  full_name='yandex.cloud.compute.v1.GetHostGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_group_id', full_name='yandex.cloud.compute.v1.GetHostGroupRequest.host_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=386,
)


_LISTHOSTGROUPSREQUEST = _descriptor.Descriptor(
  name='ListHostGroupsRequest',
  full_name='yandex.cloud.compute.v1.ListHostGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.ListHostGroupsRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListHostGroupsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListHostGroupsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.compute.v1.ListHostGroupsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=535,
)


_LISTHOSTGROUPSRESPONSE = _descriptor.Descriptor(
  name='ListHostGroupsResponse',
  full_name='yandex.cloud.compute.v1.ListHostGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_groups', full_name='yandex.cloud.compute.v1.ListHostGroupsResponse.host_groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListHostGroupsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=643,
)


_CREATEHOSTGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.CreateHostGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.CreateHostGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.CreateHostGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1134,
  serialized_end=1179,
)

_CREATEHOSTGROUPREQUEST = _descriptor.Descriptor(
  name='CreateHostGroupRequest',
  full_name='yandex.cloud.compute.v1.CreateHostGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.CreateHostGroupRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.CreateHostGroupRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.CreateHostGroupRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.CreateHostGroupRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.compute.v1.CreateHostGroupRequest.zone_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_id', full_name='yandex.cloud.compute.v1.CreateHostGroupRequest.type_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_policy', full_name='yandex.cloud.compute.v1.CreateHostGroupRequest.maintenance_policy', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale_policy', full_name='yandex.cloud.compute.v1.CreateHostGroupRequest.scale_policy', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEHOSTGROUPREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=646,
  serialized_end=1179,
)


_CREATEHOSTGROUPMETADATA = _descriptor.Descriptor(
  name='CreateHostGroupMetadata',
  full_name='yandex.cloud.compute.v1.CreateHostGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_group_id', full_name='yandex.cloud.compute.v1.CreateHostGroupMetadata.host_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1181,
  serialized_end=1229,
)


_UPDATEHOSTGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.UpdateHostGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.UpdateHostGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.UpdateHostGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1134,
  serialized_end=1179,
)

_UPDATEHOSTGROUPREQUEST = _descriptor.Descriptor(
  name='UpdateHostGroupRequest',
  full_name='yandex.cloud.compute.v1.UpdateHostGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_group_id', full_name='yandex.cloud.compute.v1.UpdateHostGroupRequest.host_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.compute.v1.UpdateHostGroupRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.UpdateHostGroupRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.UpdateHostGroupRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.UpdateHostGroupRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_policy', full_name='yandex.cloud.compute.v1.UpdateHostGroupRequest.maintenance_policy', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale_policy', full_name='yandex.cloud.compute.v1.UpdateHostGroupRequest.scale_policy', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEHOSTGROUPREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1232,
  serialized_end=1756,
)


_UPDATEHOSTGROUPMETADATA = _descriptor.Descriptor(
  name='UpdateHostGroupMetadata',
  full_name='yandex.cloud.compute.v1.UpdateHostGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_group_id', full_name='yandex.cloud.compute.v1.UpdateHostGroupMetadata.host_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1758,
  serialized_end=1806,
)


_DELETEHOSTGROUPREQUEST = _descriptor.Descriptor(
  name='DeleteHostGroupRequest',
  full_name='yandex.cloud.compute.v1.DeleteHostGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_group_id', full_name='yandex.cloud.compute.v1.DeleteHostGroupRequest.host_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1808,
  serialized_end=1869,
)


_DELETEHOSTGROUPMETADATA = _descriptor.Descriptor(
  name='DeleteHostGroupMetadata',
  full_name='yandex.cloud.compute.v1.DeleteHostGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_group_id', full_name='yandex.cloud.compute.v1.DeleteHostGroupMetadata.host_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1871,
  serialized_end=1919,
)


_LISTHOSTGROUPINSTANCESREQUEST = _descriptor.Descriptor(
  name='ListHostGroupInstancesRequest',
  full_name='yandex.cloud.compute.v1.ListHostGroupInstancesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_group_id', full_name='yandex.cloud.compute.v1.ListHostGroupInstancesRequest.host_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListHostGroupInstancesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListHostGroupInstancesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.compute.v1.ListHostGroupInstancesRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1922,
  serialized_end=2080,
)


_LISTHOSTGROUPINSTANCESRESPONSE = _descriptor.Descriptor(
  name='ListHostGroupInstancesResponse',
  full_name='yandex.cloud.compute.v1.ListHostGroupInstancesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instances', full_name='yandex.cloud.compute.v1.ListHostGroupInstancesResponse.instances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListHostGroupInstancesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2082,
  serialized_end=2193,
)


_LISTHOSTGROUPHOSTSREQUEST = _descriptor.Descriptor(
  name='ListHostGroupHostsRequest',
  full_name='yandex.cloud.compute.v1.ListHostGroupHostsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_group_id', full_name='yandex.cloud.compute.v1.ListHostGroupHostsRequest.host_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListHostGroupHostsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListHostGroupHostsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2195,
  serialized_end=2321,
)


_LISTHOSTGROUPHOSTSRESPONSE = _descriptor.Descriptor(
  name='ListHostGroupHostsResponse',
  full_name='yandex.cloud.compute.v1.ListHostGroupHostsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hosts', full_name='yandex.cloud.compute.v1.ListHostGroupHostsResponse.hosts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListHostGroupHostsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2323,
  serialized_end=2422,
)


_LISTHOSTGROUPOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListHostGroupOperationsRequest',
  full_name='yandex.cloud.compute.v1.ListHostGroupOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_group_id', full_name='yandex.cloud.compute.v1.ListHostGroupOperationsRequest.host_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListHostGroupOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListHostGroupOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2425,
  serialized_end=2556,
)


_LISTHOSTGROUPOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListHostGroupOperationsResponse',
  full_name='yandex.cloud.compute.v1.ListHostGroupOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.compute.v1.ListHostGroupOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListHostGroupOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2558,
  serialized_end=2671,
)

_LISTHOSTGROUPSRESPONSE.fields_by_name['host_groups'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__pb2._HOSTGROUP
_CREATEHOSTGROUPREQUEST_LABELSENTRY.containing_type = _CREATEHOSTGROUPREQUEST
_CREATEHOSTGROUPREQUEST.fields_by_name['labels'].message_type = _CREATEHOSTGROUPREQUEST_LABELSENTRY
_CREATEHOSTGROUPREQUEST.fields_by_name['maintenance_policy'].enum_type = yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__pb2._MAINTENANCEPOLICY
_CREATEHOSTGROUPREQUEST.fields_by_name['scale_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__pb2._SCALEPOLICY
_UPDATEHOSTGROUPREQUEST_LABELSENTRY.containing_type = _UPDATEHOSTGROUPREQUEST
_UPDATEHOSTGROUPREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEHOSTGROUPREQUEST.fields_by_name['labels'].message_type = _UPDATEHOSTGROUPREQUEST_LABELSENTRY
_UPDATEHOSTGROUPREQUEST.fields_by_name['maintenance_policy'].enum_type = yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__pb2._MAINTENANCEPOLICY
_UPDATEHOSTGROUPREQUEST.fields_by_name['scale_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__pb2._SCALEPOLICY
_LISTHOSTGROUPINSTANCESRESPONSE.fields_by_name['instances'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._INSTANCE
_LISTHOSTGROUPHOSTSRESPONSE.fields_by_name['hosts'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__pb2._HOST
_LISTHOSTGROUPOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetHostGroupRequest'] = _GETHOSTGROUPREQUEST
DESCRIPTOR.message_types_by_name['ListHostGroupsRequest'] = _LISTHOSTGROUPSREQUEST
DESCRIPTOR.message_types_by_name['ListHostGroupsResponse'] = _LISTHOSTGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['CreateHostGroupRequest'] = _CREATEHOSTGROUPREQUEST
DESCRIPTOR.message_types_by_name['CreateHostGroupMetadata'] = _CREATEHOSTGROUPMETADATA
DESCRIPTOR.message_types_by_name['UpdateHostGroupRequest'] = _UPDATEHOSTGROUPREQUEST
DESCRIPTOR.message_types_by_name['UpdateHostGroupMetadata'] = _UPDATEHOSTGROUPMETADATA
DESCRIPTOR.message_types_by_name['DeleteHostGroupRequest'] = _DELETEHOSTGROUPREQUEST
DESCRIPTOR.message_types_by_name['DeleteHostGroupMetadata'] = _DELETEHOSTGROUPMETADATA
DESCRIPTOR.message_types_by_name['ListHostGroupInstancesRequest'] = _LISTHOSTGROUPINSTANCESREQUEST
DESCRIPTOR.message_types_by_name['ListHostGroupInstancesResponse'] = _LISTHOSTGROUPINSTANCESRESPONSE
DESCRIPTOR.message_types_by_name['ListHostGroupHostsRequest'] = _LISTHOSTGROUPHOSTSREQUEST
DESCRIPTOR.message_types_by_name['ListHostGroupHostsResponse'] = _LISTHOSTGROUPHOSTSRESPONSE
DESCRIPTOR.message_types_by_name['ListHostGroupOperationsRequest'] = _LISTHOSTGROUPOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListHostGroupOperationsResponse'] = _LISTHOSTGROUPOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetHostGroupRequest = _reflection.GeneratedProtocolMessageType('GetHostGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETHOSTGROUPREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.host_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.GetHostGroupRequest)
  })
_sym_db.RegisterMessage(GetHostGroupRequest)

ListHostGroupsRequest = _reflection.GeneratedProtocolMessageType('ListHostGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTHOSTGROUPSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.host_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListHostGroupsRequest)
  })
_sym_db.RegisterMessage(ListHostGroupsRequest)

ListHostGroupsResponse = _reflection.GeneratedProtocolMessageType('ListHostGroupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTHOSTGROUPSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.host_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListHostGroupsResponse)
  })
_sym_db.RegisterMessage(ListHostGroupsResponse)

CreateHostGroupRequest = _reflection.GeneratedProtocolMessageType('CreateHostGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEHOSTGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.host_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateHostGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEHOSTGROUPREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.host_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateHostGroupRequest)
  })
_sym_db.RegisterMessage(CreateHostGroupRequest)
_sym_db.RegisterMessage(CreateHostGroupRequest.LabelsEntry)

CreateHostGroupMetadata = _reflection.GeneratedProtocolMessageType('CreateHostGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEHOSTGROUPMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.host_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateHostGroupMetadata)
  })
_sym_db.RegisterMessage(CreateHostGroupMetadata)

UpdateHostGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateHostGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEHOSTGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.host_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateHostGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEHOSTGROUPREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.host_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateHostGroupRequest)
  })
_sym_db.RegisterMessage(UpdateHostGroupRequest)
_sym_db.RegisterMessage(UpdateHostGroupRequest.LabelsEntry)

UpdateHostGroupMetadata = _reflection.GeneratedProtocolMessageType('UpdateHostGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEHOSTGROUPMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.host_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateHostGroupMetadata)
  })
_sym_db.RegisterMessage(UpdateHostGroupMetadata)

DeleteHostGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteHostGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEHOSTGROUPREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.host_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DeleteHostGroupRequest)
  })
_sym_db.RegisterMessage(DeleteHostGroupRequest)

DeleteHostGroupMetadata = _reflection.GeneratedProtocolMessageType('DeleteHostGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEHOSTGROUPMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.host_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DeleteHostGroupMetadata)
  })
_sym_db.RegisterMessage(DeleteHostGroupMetadata)

ListHostGroupInstancesRequest = _reflection.GeneratedProtocolMessageType('ListHostGroupInstancesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTHOSTGROUPINSTANCESREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.host_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListHostGroupInstancesRequest)
  })
_sym_db.RegisterMessage(ListHostGroupInstancesRequest)

ListHostGroupInstancesResponse = _reflection.GeneratedProtocolMessageType('ListHostGroupInstancesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTHOSTGROUPINSTANCESRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.host_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListHostGroupInstancesResponse)
  })
_sym_db.RegisterMessage(ListHostGroupInstancesResponse)

ListHostGroupHostsRequest = _reflection.GeneratedProtocolMessageType('ListHostGroupHostsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTHOSTGROUPHOSTSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.host_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListHostGroupHostsRequest)
  })
_sym_db.RegisterMessage(ListHostGroupHostsRequest)

ListHostGroupHostsResponse = _reflection.GeneratedProtocolMessageType('ListHostGroupHostsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTHOSTGROUPHOSTSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.host_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListHostGroupHostsResponse)
  })
_sym_db.RegisterMessage(ListHostGroupHostsResponse)

ListHostGroupOperationsRequest = _reflection.GeneratedProtocolMessageType('ListHostGroupOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTHOSTGROUPOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.host_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListHostGroupOperationsRequest)
  })
_sym_db.RegisterMessage(ListHostGroupOperationsRequest)

ListHostGroupOperationsResponse = _reflection.GeneratedProtocolMessageType('ListHostGroupOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTHOSTGROUPOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.host_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListHostGroupOperationsResponse)
  })
_sym_db.RegisterMessage(ListHostGroupOperationsResponse)


DESCRIPTOR._options = None
_GETHOSTGROUPREQUEST.fields_by_name['host_group_id']._options = None
_LISTHOSTGROUPSREQUEST.fields_by_name['folder_id']._options = None
_LISTHOSTGROUPSREQUEST.fields_by_name['page_size']._options = None
_LISTHOSTGROUPSREQUEST.fields_by_name['page_token']._options = None
_LISTHOSTGROUPSREQUEST.fields_by_name['filter']._options = None
_CREATEHOSTGROUPREQUEST_LABELSENTRY._options = None
_CREATEHOSTGROUPREQUEST.fields_by_name['folder_id']._options = None
_CREATEHOSTGROUPREQUEST.fields_by_name['name']._options = None
_CREATEHOSTGROUPREQUEST.fields_by_name['description']._options = None
_CREATEHOSTGROUPREQUEST.fields_by_name['labels']._options = None
_CREATEHOSTGROUPREQUEST.fields_by_name['zone_id']._options = None
_CREATEHOSTGROUPREQUEST.fields_by_name['type_id']._options = None
_UPDATEHOSTGROUPREQUEST_LABELSENTRY._options = None
_UPDATEHOSTGROUPREQUEST.fields_by_name['host_group_id']._options = None
_UPDATEHOSTGROUPREQUEST.fields_by_name['name']._options = None
_UPDATEHOSTGROUPREQUEST.fields_by_name['description']._options = None
_UPDATEHOSTGROUPREQUEST.fields_by_name['labels']._options = None
_DELETEHOSTGROUPREQUEST.fields_by_name['host_group_id']._options = None
_LISTHOSTGROUPINSTANCESREQUEST.fields_by_name['host_group_id']._options = None
_LISTHOSTGROUPINSTANCESREQUEST.fields_by_name['page_size']._options = None
_LISTHOSTGROUPINSTANCESREQUEST.fields_by_name['page_token']._options = None
_LISTHOSTGROUPINSTANCESREQUEST.fields_by_name['filter']._options = None
_LISTHOSTGROUPHOSTSREQUEST.fields_by_name['host_group_id']._options = None
_LISTHOSTGROUPHOSTSREQUEST.fields_by_name['page_size']._options = None
_LISTHOSTGROUPHOSTSREQUEST.fields_by_name['page_token']._options = None
_LISTHOSTGROUPOPERATIONSREQUEST.fields_by_name['host_group_id']._options = None
_LISTHOSTGROUPOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTHOSTGROUPOPERATIONSREQUEST.fields_by_name['page_token']._options = None

_HOSTGROUPSERVICE = _descriptor.ServiceDescriptor(
  name='HostGroupService',
  full_name='yandex.cloud.compute.v1.HostGroupService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2674,
  serialized_end=4074,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.compute.v1.HostGroupService.Get',
    index=0,
    containing_service=None,
    input_type=_GETHOSTGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_compute_dot_v1_dot_host__group__pb2._HOSTGROUP,
    serialized_options=b'\202\323\344\223\002(\022&/compute/v1/hostGroups/{host_group_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.compute.v1.HostGroupService.List',
    index=1,
    containing_service=None,
    input_type=_LISTHOSTGROUPSREQUEST,
    output_type=_LISTHOSTGROUPSRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/compute/v1/hostGroups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.compute.v1.HostGroupService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEHOSTGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\033\"\026/compute/v1/hostGroups:\001*\262\322*$\n\027CreateHostGroupMetadata\022\tHostGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.compute.v1.HostGroupService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEHOSTGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002+2&/compute/v1/hostGroups/{host_group_id}:\001*\262\322*$\n\027UpdateHostGroupMetadata\022\tHostGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.compute.v1.HostGroupService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEHOSTGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002(*&/compute/v1/hostGroups/{host_group_id}\262\322*0\n\027DeleteHostGroupMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.compute.v1.HostGroupService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTHOSTGROUPOPERATIONSREQUEST,
    output_type=_LISTHOSTGROUPOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0023\0221/compute/v1/hostGroups/{host_group_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListInstances',
    full_name='yandex.cloud.compute.v1.HostGroupService.ListInstances',
    index=6,
    containing_service=None,
    input_type=_LISTHOSTGROUPINSTANCESREQUEST,
    output_type=_LISTHOSTGROUPINSTANCESRESPONSE,
    serialized_options=b'\202\323\344\223\0022\0220/compute/v1/hostGroups/{host_group_id}/instances',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListHosts',
    full_name='yandex.cloud.compute.v1.HostGroupService.ListHosts',
    index=7,
    containing_service=None,
    input_type=_LISTHOSTGROUPHOSTSREQUEST,
    output_type=_LISTHOSTGROUPHOSTSRESPONSE,
    serialized_options=b'\202\323\344\223\002.\022,/compute/v1/hostGroups/{host_group_id}/hosts',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_HOSTGROUPSERVICE)

DESCRIPTOR.services_by_name['HostGroupService'] = _HOSTGROUPSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/agent/v1/job_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/loadtesting/agent/v1/job_service.proto',
  package='yandex.cloud.loadtesting.agent.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3yandex/cloud/loadtesting/agent/v1/job_service.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a\x1cgoogle/api/annotations.proto\"\xe4\x02\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12\x35\n\x04\x61mmo\x18\x03 \x01(\x0b\x32\'.yandex.cloud.loadtesting.agent.v1.File\x12\x1c\n\x14logging_log_group_id\x18\x04 \x01(\t\x12\x43\n\ttest_data\x18\x05 \x01(\x0b\x32\x30.yandex.cloud.loadtesting.agent.v1.StorageObject\x12\x46\n\x0c\x64\x61ta_payload\x18\x06 \x03(\x0b\x32\x30.yandex.cloud.loadtesting.agent.v1.TestDataEntry\x12_\n\x18\x61rtifact_upload_settings\x18\x07 \x01(\x0b\x32=.yandex.cloud.loadtesting.agent.v1.TestArtifactUploadSettings\"%\n\x04\x46ile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"O\n\rStorageObject\x12\x1d\n\x15object_storage_bucket\x18\x01 \x01(\t\x12\x1f\n\x17object_storage_filename\x18\x02 \x01(\t\"}\n\rTestDataEntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cis_transient\x18\x02 \x01(\x08\x12H\n\x0estorage_object\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.loadtesting.agent.v1.StorageObject\"\x8c\x01\n\x1aTestArtifactUploadSettings\x12\x15\n\routput_bucket\x18\x01 \x01(\t\x12\x13\n\x0boutput_name\x18\x02 \x01(\t\x12\x12\n\nis_archive\x18\x03 \x01(\x08\x12\x16\n\x0e\x66ilter_include\x18\x04 \x03(\t\x12\x16\n\x0e\x66ilter_exclude\x18\x05 \x03(\t\"3\n\x13GetJobTransientFile\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"W\n\rGetJobRequest\x12\x1b\n\x13\x63ompute_instance_id\x18\x01 \x01(\t\x12\x19\n\x11\x61gent_instance_id\x18\x02 \x01(\t\x12\x0e\n\x06job_id\x18\x03 \x01(\t\"\xe9\x02\n\x15\x43laimJobStatusRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12R\n\x06status\x18\x02 \x01(\x0e\x32\x42.yandex.cloud.loadtesting.agent.v1.ClaimJobStatusRequest.JobStatus\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"\xdc\x01\n\tJobStatus\x12\x1a\n\x16JOB_STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPOST_PROCESS\x10\x01\x12\r\n\tINITIATED\x10\x02\x12\r\n\tPREPARING\x10\x03\x12\r\n\tNOT_FOUND\x10\x04\x12\x0b\n\x07RUNNING\x10\x05\x12\r\n\tFINISHING\x10\x06\x12\x0c\n\x08\x46INISHED\x10\x07\x12\x0b\n\x07STOPPED\x10\x08\x12\n\n\x06\x46\x41ILED\x10\t\x12\x0f\n\x0b\x41UTOSTOPPED\x10\n\x12 \n\x1cWAITING_FOR_A_COMMAND_TO_RUN\x10\x0b\"&\n\x16\x43laimJobStatusResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\"\"\n\x10JobSignalRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\xc9\x01\n\x11JobSignalResponse\x12K\n\x06signal\x18\x01 \x01(\x0e\x32;.yandex.cloud.loadtesting.agent.v1.JobSignalResponse.Signal\x12\x15\n\rwait_duration\x18\x02 \x01(\x01\x12\x0e\n\x06run_in\x18\x03 \x01(\x01\"@\n\x06Signal\x12\x16\n\x12SIGNAL_UNSPECIFIED\x10\x00\x12\x08\n\x04STOP\x10\x01\x12\x08\n\x04WAIT\x10\x02\x12\n\n\x06RUN_IN\x10\x03\x32\xfb\x05\n\nJobService\x12\xbe\x01\n\x0b\x43laimStatus\x12\x38.yandex.cloud.loadtesting.agent.v1.ClaimJobStatusRequest\x1a\x39.yandex.cloud.loadtesting.agent.v1.ClaimJobStatusResponse\":\x82\xd3\xe4\x93\x02\x34\"//loadtesting/agent/v1/jobs/{job_id}/claimStatus:\x01*\x12\xc7\x01\n\x03Get\x12\x30.yandex.cloud.loadtesting.agent.v1.GetJobRequest\x1a&.yandex.cloud.loadtesting.agent.v1.Job\"f\x82\xd3\xe4\x93\x02`\x12\x37/loadtesting/agent/v1/agents/{agent_instance_id}/getJobZ%\x12#/loadtesting/agent/v1/jobs/{job_id}\x12\xad\x01\n\tGetSignal\x12\x33.yandex.cloud.loadtesting.agent.v1.JobSignalRequest\x1a\x34.yandex.cloud.loadtesting.agent.v1.JobSignalResponse\"5\x82\xd3\xe4\x93\x02/\x12-/loadtesting/agent/v1/jobs/{job_id}/getSignal\x12\xb1\x01\n\x10GetTransientFile\x12\x36.yandex.cloud.loadtesting.agent.v1.GetJobTransientFile\x1a\'.yandex.cloud.loadtesting.agent.v1.File\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/loadtesting/agent/v1/jobs/{job_id}/getTransientFileBt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_CLAIMJOBSTATUSREQUEST_JOBSTATUS = _descriptor.EnumDescriptor(
  name='JobStatus',
  full_name='yandex.cloud.loadtesting.agent.v1.ClaimJobStatusRequest.JobStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='JOB_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POST_PROCESS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INITIATED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREPARING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_FOUND', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FINISHING', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FINISHED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTOSTOPPED', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAITING_FOR_A_COMMAND_TO_RUN', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1153,
  serialized_end=1373,
)
_sym_db.RegisterEnumDescriptor(_CLAIMJOBSTATUSREQUEST_JOBSTATUS)

_JOBSIGNALRESPONSE_SIGNAL = _descriptor.EnumDescriptor(
  name='Signal',
  full_name='yandex.cloud.loadtesting.agent.v1.JobSignalResponse.Signal',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SIGNAL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAIT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUN_IN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1589,
  serialized_end=1653,
)
_sym_db.RegisterEnumDescriptor(_JOBSIGNALRESPONSE_SIGNAL)


_JOB = _descriptor.Descriptor(
  name='Job',
  full_name='yandex.cloud.loadtesting.agent.v1.Job',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.loadtesting.agent.v1.Job.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.loadtesting.agent.v1.Job.config', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ammo', full_name='yandex.cloud.loadtesting.agent.v1.Job.ammo', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logging_log_group_id', full_name='yandex.cloud.loadtesting.agent.v1.Job.logging_log_group_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='test_data', full_name='yandex.cloud.loadtesting.agent.v1.Job.test_data', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_payload', full_name='yandex.cloud.loadtesting.agent.v1.Job.data_payload', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='artifact_upload_settings', full_name='yandex.cloud.loadtesting.agent.v1.Job.artifact_upload_settings', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=477,
)


_FILE = _descriptor.Descriptor(
  name='File',
  full_name='yandex.cloud.loadtesting.agent.v1.File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.loadtesting.agent.v1.File.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='yandex.cloud.loadtesting.agent.v1.File.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=479,
  serialized_end=516,
)


_STORAGEOBJECT = _descriptor.Descriptor(
  name='StorageObject',
  full_name='yandex.cloud.loadtesting.agent.v1.StorageObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object_storage_bucket', full_name='yandex.cloud.loadtesting.agent.v1.StorageObject.object_storage_bucket', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_storage_filename', full_name='yandex.cloud.loadtesting.agent.v1.StorageObject.object_storage_filename', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=518,
  serialized_end=597,
)


_TESTDATAENTRY = _descriptor.Descriptor(
  name='TestDataEntry',
  full_name='yandex.cloud.loadtesting.agent.v1.TestDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.loadtesting.agent.v1.TestDataEntry.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_transient', full_name='yandex.cloud.loadtesting.agent.v1.TestDataEntry.is_transient', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_object', full_name='yandex.cloud.loadtesting.agent.v1.TestDataEntry.storage_object', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=599,
  serialized_end=724,
)


_TESTARTIFACTUPLOADSETTINGS = _descriptor.Descriptor(
  name='TestArtifactUploadSettings',
  full_name='yandex.cloud.loadtesting.agent.v1.TestArtifactUploadSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_bucket', full_name='yandex.cloud.loadtesting.agent.v1.TestArtifactUploadSettings.output_bucket', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_name', full_name='yandex.cloud.loadtesting.agent.v1.TestArtifactUploadSettings.output_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_archive', full_name='yandex.cloud.loadtesting.agent.v1.TestArtifactUploadSettings.is_archive', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_include', full_name='yandex.cloud.loadtesting.agent.v1.TestArtifactUploadSettings.filter_include', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_exclude', full_name='yandex.cloud.loadtesting.agent.v1.TestArtifactUploadSettings.filter_exclude', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=727,
  serialized_end=867,
)


_GETJOBTRANSIENTFILE = _descriptor.Descriptor(
  name='GetJobTransientFile',
  full_name='yandex.cloud.loadtesting.agent.v1.GetJobTransientFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='yandex.cloud.loadtesting.agent.v1.GetJobTransientFile.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.loadtesting.agent.v1.GetJobTransientFile.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=869,
  serialized_end=920,
)


_GETJOBREQUEST = _descriptor.Descriptor(
  name='GetJobRequest',
  full_name='yandex.cloud.loadtesting.agent.v1.GetJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='compute_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.GetJobRequest.compute_instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agent_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.GetJobRequest.agent_instance_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='yandex.cloud.loadtesting.agent.v1.GetJobRequest.job_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=922,
  serialized_end=1009,
)


_CLAIMJOBSTATUSREQUEST = _descriptor.Descriptor(
  name='ClaimJobStatusRequest',
  full_name='yandex.cloud.loadtesting.agent.v1.ClaimJobStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='yandex.cloud.loadtesting.agent.v1.ClaimJobStatusRequest.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.loadtesting.agent.v1.ClaimJobStatusRequest.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='yandex.cloud.loadtesting.agent.v1.ClaimJobStatusRequest.error', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLAIMJOBSTATUSREQUEST_JOBSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1012,
  serialized_end=1373,
)


_CLAIMJOBSTATUSRESPONSE = _descriptor.Descriptor(
  name='ClaimJobStatusResponse',
  full_name='yandex.cloud.loadtesting.agent.v1.ClaimJobStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='yandex.cloud.loadtesting.agent.v1.ClaimJobStatusResponse.code', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1375,
  serialized_end=1413,
)


_JOBSIGNALREQUEST = _descriptor.Descriptor(
  name='JobSignalRequest',
  full_name='yandex.cloud.loadtesting.agent.v1.JobSignalRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='yandex.cloud.loadtesting.agent.v1.JobSignalRequest.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1415,
  serialized_end=1449,
)


_JOBSIGNALRESPONSE = _descriptor.Descriptor(
  name='JobSignalResponse',
  full_name='yandex.cloud.loadtesting.agent.v1.JobSignalResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signal', full_name='yandex.cloud.loadtesting.agent.v1.JobSignalResponse.signal', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait_duration', full_name='yandex.cloud.loadtesting.agent.v1.JobSignalResponse.wait_duration', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run_in', full_name='yandex.cloud.loadtesting.agent.v1.JobSignalResponse.run_in', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _JOBSIGNALRESPONSE_SIGNAL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1452,
  serialized_end=1653,
)

_JOB.fields_by_name['ammo'].message_type = _FILE
_JOB.fields_by_name['test_data'].message_type = _STORAGEOBJECT
_JOB.fields_by_name['data_payload'].message_type = _TESTDATAENTRY
_JOB.fields_by_name['artifact_upload_settings'].message_type = _TESTARTIFACTUPLOADSETTINGS
_TESTDATAENTRY.fields_by_name['storage_object'].message_type = _STORAGEOBJECT
_CLAIMJOBSTATUSREQUEST.fields_by_name['status'].enum_type = _CLAIMJOBSTATUSREQUEST_JOBSTATUS
_CLAIMJOBSTATUSREQUEST_JOBSTATUS.containing_type = _CLAIMJOBSTATUSREQUEST
_JOBSIGNALRESPONSE.fields_by_name['signal'].enum_type = _JOBSIGNALRESPONSE_SIGNAL
_JOBSIGNALRESPONSE_SIGNAL.containing_type = _JOBSIGNALRESPONSE
DESCRIPTOR.message_types_by_name['Job'] = _JOB
DESCRIPTOR.message_types_by_name['File'] = _FILE
DESCRIPTOR.message_types_by_name['StorageObject'] = _STORAGEOBJECT
DESCRIPTOR.message_types_by_name['TestDataEntry'] = _TESTDATAENTRY
DESCRIPTOR.message_types_by_name['TestArtifactUploadSettings'] = _TESTARTIFACTUPLOADSETTINGS
DESCRIPTOR.message_types_by_name['GetJobTransientFile'] = _GETJOBTRANSIENTFILE
DESCRIPTOR.message_types_by_name['GetJobRequest'] = _GETJOBREQUEST
DESCRIPTOR.message_types_by_name['ClaimJobStatusRequest'] = _CLAIMJOBSTATUSREQUEST
DESCRIPTOR.message_types_by_name['ClaimJobStatusResponse'] = _CLAIMJOBSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['JobSignalRequest'] = _JOBSIGNALREQUEST
DESCRIPTOR.message_types_by_name['JobSignalResponse'] = _JOBSIGNALRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Job = _reflection.GeneratedProtocolMessageType('Job', (_message.Message,), {
  'DESCRIPTOR' : _JOB,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.Job)
  })
_sym_db.RegisterMessage(Job)

File = _reflection.GeneratedProtocolMessageType('File', (_message.Message,), {
  'DESCRIPTOR' : _FILE,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.File)
  })
_sym_db.RegisterMessage(File)

StorageObject = _reflection.GeneratedProtocolMessageType('StorageObject', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEOBJECT,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.StorageObject)
  })
_sym_db.RegisterMessage(StorageObject)

TestDataEntry = _reflection.GeneratedProtocolMessageType('TestDataEntry', (_message.Message,), {
  'DESCRIPTOR' : _TESTDATAENTRY,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.TestDataEntry)
  })
_sym_db.RegisterMessage(TestDataEntry)

TestArtifactUploadSettings = _reflection.GeneratedProtocolMessageType('TestArtifactUploadSettings', (_message.Message,), {
  'DESCRIPTOR' : _TESTARTIFACTUPLOADSETTINGS,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.TestArtifactUploadSettings)
  })
_sym_db.RegisterMessage(TestArtifactUploadSettings)

GetJobTransientFile = _reflection.GeneratedProtocolMessageType('GetJobTransientFile', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBTRANSIENTFILE,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.GetJobTransientFile)
  })
_sym_db.RegisterMessage(GetJobTransientFile)

GetJobRequest = _reflection.GeneratedProtocolMessageType('GetJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.GetJobRequest)
  })
_sym_db.RegisterMessage(GetJobRequest)

ClaimJobStatusRequest = _reflection.GeneratedProtocolMessageType('ClaimJobStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLAIMJOBSTATUSREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.ClaimJobStatusRequest)
  })
_sym_db.RegisterMessage(ClaimJobStatusRequest)

ClaimJobStatusResponse = _reflection.GeneratedProtocolMessageType('ClaimJobStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLAIMJOBSTATUSRESPONSE,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.ClaimJobStatusResponse)
  })
_sym_db.RegisterMessage(ClaimJobStatusResponse)

JobSignalRequest = _reflection.GeneratedProtocolMessageType('JobSignalRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOBSIGNALREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.JobSignalRequest)
  })
_sym_db.RegisterMessage(JobSignalRequest)

JobSignalResponse = _reflection.GeneratedProtocolMessageType('JobSignalResponse', (_message.Message,), {
  'DESCRIPTOR' : _JOBSIGNALRESPONSE,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.job_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.JobSignalResponse)
  })
_sym_db.RegisterMessage(JobSignalResponse)


DESCRIPTOR._options = None

_JOBSERVICE = _descriptor.ServiceDescriptor(
  name='JobService',
  full_name='yandex.cloud.loadtesting.agent.v1.JobService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1656,
  serialized_end=2419,
  methods=[
  _descriptor.MethodDescriptor(
    name='ClaimStatus',
    full_name='yandex.cloud.loadtesting.agent.v1.JobService.ClaimStatus',
    index=0,
    containing_service=None,
    input_type=_CLAIMJOBSTATUSREQUEST,
    output_type=_CLAIMJOBSTATUSRESPONSE,
    serialized_options=b'\202\323\344\223\0024\"//loadtesting/agent/v1/jobs/{job_id}/claimStatus:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.loadtesting.agent.v1.JobService.Get',
    index=1,
    containing_service=None,
    input_type=_GETJOBREQUEST,
    output_type=_JOB,
    serialized_options=b'\202\323\344\223\002`\0227/loadtesting/agent/v1/agents/{agent_instance_id}/getJobZ%\022#/loadtesting/agent/v1/jobs/{job_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSignal',
    full_name='yandex.cloud.loadtesting.agent.v1.JobService.GetSignal',
    index=2,
    containing_service=None,
    input_type=_JOBSIGNALREQUEST,
    output_type=_JOBSIGNALRESPONSE,
    serialized_options=b'\202\323\344\223\002/\022-/loadtesting/agent/v1/jobs/{job_id}/getSignal',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTransientFile',
    full_name='yandex.cloud.loadtesting.agent.v1.JobService.GetTransientFile',
    index=3,
    containing_service=None,
    input_type=_GETJOBTRANSIENTFILE,
    output_type=_FILE,
    serialized_options=b'\202\323\344\223\0026\0224/loadtesting/agent/v1/jobs/{job_id}/getTransientFile',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_JOBSERVICE)

DESCRIPTOR.services_by_name['JobService'] = _JOBSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/postgresql/v1/database_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.mdb.postgresql.v1 import database_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_database__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/postgresql/v1/database_service.proto',
  package='yandex.cloud.mdb.postgresql.v1',
  syntax='proto3',
  serialized_options=b'\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresql',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5yandex/cloud/mdb/postgresql/v1/database_service.proto\x12\x1eyandex.cloud.mdb.postgresql.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a&yandex/cloud/operation/operation.proto\x1a-yandex/cloud/mdb/postgresql/v1/database.proto\"m\n\x12GetDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rdatabase_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\"v\n\x14ListDatabasesRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"m\n\x15ListDatabasesResponse\x12;\n\tdatabases\x18\x01 \x03(\x0b\x32(.yandex.cloud.mdb.postgresql.v1.Database\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x84\x01\n\x15\x43reateDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12I\n\rdatabase_spec\x18\x02 \x01(\x0b\x32,.yandex.cloud.mdb.postgresql.v1.DatabaseSpecB\x04\xe8\xc7\x31\x01\"C\n\x16\x43reateDatabaseMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"\xd4\x02\n\x15UpdateDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rdatabase_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12\x39\n\x11new_database_name\x18\x05 \x01(\tB\x1e\xe8\xc7\x31\x00\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12=\n\nextensions\x18\x04 \x03(\x0b\x32).yandex.cloud.mdb.postgresql.v1.Extension\x12\x37\n\x13\x64\x65letion_protection\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"C\n\x16UpdateDatabaseMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"p\n\x15\x44\x65leteDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rdatabase_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\"C\n\x16\x44\x65leteDatabaseMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t2\x92\x08\n\x0f\x44\x61tabaseService\x12\xb3\x01\n\x03Get\x12\x32.yandex.cloud.mdb.postgresql.v1.GetDatabaseRequest\x1a(.yandex.cloud.mdb.postgresql.v1.Database\"N\x82\xd3\xe4\x93\x02H\x12\x46/managed-postgresql/v1/clusters/{cluster_id}/databases/{database_name}\x12\xb3\x01\n\x04List\x12\x34.yandex.cloud.mdb.postgresql.v1.ListDatabasesRequest\x1a\x35.yandex.cloud.mdb.postgresql.v1.ListDatabasesResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/managed-postgresql/v1/clusters/{cluster_id}/databases\x12\xcb\x01\n\x06\x43reate\x12\x35.yandex.cloud.mdb.postgresql.v1.CreateDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"g\x82\xd3\xe4\x93\x02;\"6/managed-postgresql/v1/clusters/{cluster_id}/databases:\x01*\xb2\xd2*\"\n\x16\x43reateDatabaseMetadata\x12\x08\x44\x61tabase\x12\xdb\x01\n\x06Update\x12\x35.yandex.cloud.mdb.postgresql.v1.UpdateDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"w\x82\xd3\xe4\x93\x02K2F/managed-postgresql/v1/clusters/{cluster_id}/databases/{database_name}:\x01*\xb2\xd2*\"\n\x16UpdateDatabaseMetadata\x12\x08\x44\x61tabase\x12\xe6\x01\n\x06\x44\x65lete\x12\x35.yandex.cloud.mdb.postgresql.v1.DeleteDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"\x81\x01\x82\xd3\xe4\x93\x02H*F/managed-postgresql/v1/clusters/{cluster_id}/databases/{database_name}\xb2\xd2*/\n\x16\x44\x65leteDatabaseMetadata\x12\x15google.protobuf.EmptyBs\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresqlb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_database__pb2.DESCRIPTOR,])




_GETDATABASEREQUEST = _descriptor.Descriptor(
  name='GetDatabaseRequest',
  full_name='yandex.cloud.mdb.postgresql.v1.GetDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.postgresql.v1.GetDatabaseRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.postgresql.v1.GetDatabaseRequest.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=337,
  serialized_end=446,
)


_LISTDATABASESREQUEST = _descriptor.Descriptor(
  name='ListDatabasesRequest',
  full_name='yandex.cloud.mdb.postgresql.v1.ListDatabasesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.postgresql.v1.ListDatabasesRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.mdb.postgresql.v1.ListDatabasesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.mdb.postgresql.v1.ListDatabasesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=448,
  serialized_end=566,
)


_LISTDATABASESRESPONSE = _descriptor.Descriptor(
  name='ListDatabasesResponse',
  full_name='yandex.cloud.mdb.postgresql.v1.ListDatabasesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='databases', full_name='yandex.cloud.mdb.postgresql.v1.ListDatabasesResponse.databases', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.mdb.postgresql.v1.ListDatabasesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=677,
)


_CREATEDATABASEREQUEST = _descriptor.Descriptor(
  name='CreateDatabaseRequest',
  full_name='yandex.cloud.mdb.postgresql.v1.CreateDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.postgresql.v1.CreateDatabaseRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_spec', full_name='yandex.cloud.mdb.postgresql.v1.CreateDatabaseRequest.database_spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=680,
  serialized_end=812,
)


_CREATEDATABASEMETADATA = _descriptor.Descriptor(
  name='CreateDatabaseMetadata',
  full_name='yandex.cloud.mdb.postgresql.v1.CreateDatabaseMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.postgresql.v1.CreateDatabaseMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.postgresql.v1.CreateDatabaseMetadata.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=814,
  serialized_end=881,
)


_UPDATEDATABASEREQUEST = _descriptor.Descriptor(
  name='UpdateDatabaseRequest',
  full_name='yandex.cloud.mdb.postgresql.v1.UpdateDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.postgresql.v1.UpdateDatabaseRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.postgresql.v1.UpdateDatabaseRequest.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_database_name', full_name='yandex.cloud.mdb.postgresql.v1.UpdateDatabaseRequest.new_database_name', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\000\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.mdb.postgresql.v1.UpdateDatabaseRequest.update_mask', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extensions', full_name='yandex.cloud.mdb.postgresql.v1.UpdateDatabaseRequest.extensions', index=4,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.mdb.postgresql.v1.UpdateDatabaseRequest.deletion_protection', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=884,
  serialized_end=1224,
)


_UPDATEDATABASEMETADATA = _descriptor.Descriptor(
  name='UpdateDatabaseMetadata',
  full_name='yandex.cloud.mdb.postgresql.v1.UpdateDatabaseMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.postgresql.v1.UpdateDatabaseMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.postgresql.v1.UpdateDatabaseMetadata.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1226,
  serialized_end=1293,
)


_DELETEDATABASEREQUEST = _descriptor.Descriptor(
  name='DeleteDatabaseRequest',
  full_name='yandex.cloud.mdb.postgresql.v1.DeleteDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.postgresql.v1.DeleteDatabaseRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.postgresql.v1.DeleteDatabaseRequest.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1295,
  serialized_end=1407,
)


_DELETEDATABASEMETADATA = _descriptor.Descriptor(
  name='DeleteDatabaseMetadata',
  full_name='yandex.cloud.mdb.postgresql.v1.DeleteDatabaseMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.postgresql.v1.DeleteDatabaseMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_name', full_name='yandex.cloud.mdb.postgresql.v1.DeleteDatabaseMetadata.database_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1409,
  serialized_end=1476,
)

_LISTDATABASESRESPONSE.fields_by_name['databases'].message_type = yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_database__pb2._DATABASE
_CREATEDATABASEREQUEST.fields_by_name['database_spec'].message_type = yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_database__pb2._DATABASESPEC
_UPDATEDATABASEREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEDATABASEREQUEST.fields_by_name['extensions'].message_type = yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_database__pb2._EXTENSION
_UPDATEDATABASEREQUEST.fields_by_name['deletion_protection'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
DESCRIPTOR.message_types_by_name['GetDatabaseRequest'] = _GETDATABASEREQUEST
DESCRIPTOR.message_types_by_name['ListDatabasesRequest'] = _LISTDATABASESREQUEST
DESCRIPTOR.message_types_by_name['ListDatabasesResponse'] = _LISTDATABASESRESPONSE
DESCRIPTOR.message_types_by_name['CreateDatabaseRequest'] = _CREATEDATABASEREQUEST
DESCRIPTOR.message_types_by_name['CreateDatabaseMetadata'] = _CREATEDATABASEMETADATA
DESCRIPTOR.message_types_by_name['UpdateDatabaseRequest'] = _UPDATEDATABASEREQUEST
DESCRIPTOR.message_types_by_name['UpdateDatabaseMetadata'] = _UPDATEDATABASEMETADATA
DESCRIPTOR.message_types_by_name['DeleteDatabaseRequest'] = _DELETEDATABASEREQUEST
DESCRIPTOR.message_types_by_name['DeleteDatabaseMetadata'] = _DELETEDATABASEMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetDatabaseRequest = _reflection.GeneratedProtocolMessageType('GetDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABASEREQUEST,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.GetDatabaseRequest)
  })
_sym_db.RegisterMessage(GetDatabaseRequest)

ListDatabasesRequest = _reflection.GeneratedProtocolMessageType('ListDatabasesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATABASESREQUEST,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.ListDatabasesRequest)
  })
_sym_db.RegisterMessage(ListDatabasesRequest)

ListDatabasesResponse = _reflection.GeneratedProtocolMessageType('ListDatabasesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATABASESRESPONSE,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.ListDatabasesResponse)
  })
_sym_db.RegisterMessage(ListDatabasesResponse)

CreateDatabaseRequest = _reflection.GeneratedProtocolMessageType('CreateDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATABASEREQUEST,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.CreateDatabaseRequest)
  })
_sym_db.RegisterMessage(CreateDatabaseRequest)

CreateDatabaseMetadata = _reflection.GeneratedProtocolMessageType('CreateDatabaseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATABASEMETADATA,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.CreateDatabaseMetadata)
  })
_sym_db.RegisterMessage(CreateDatabaseMetadata)

UpdateDatabaseRequest = _reflection.GeneratedProtocolMessageType('UpdateDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATABASEREQUEST,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.UpdateDatabaseRequest)
  })
_sym_db.RegisterMessage(UpdateDatabaseRequest)

UpdateDatabaseMetadata = _reflection.GeneratedProtocolMessageType('UpdateDatabaseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATABASEMETADATA,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.UpdateDatabaseMetadata)
  })
_sym_db.RegisterMessage(UpdateDatabaseMetadata)

DeleteDatabaseRequest = _reflection.GeneratedProtocolMessageType('DeleteDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATABASEREQUEST,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.DeleteDatabaseRequest)
  })
_sym_db.RegisterMessage(DeleteDatabaseRequest)

DeleteDatabaseMetadata = _reflection.GeneratedProtocolMessageType('DeleteDatabaseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATABASEMETADATA,
  '__module__' : 'yandex.cloud.mdb.postgresql.v1.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.postgresql.v1.DeleteDatabaseMetadata)
  })
_sym_db.RegisterMessage(DeleteDatabaseMetadata)


DESCRIPTOR._options = None
_GETDATABASEREQUEST.fields_by_name['cluster_id']._options = None
_GETDATABASEREQUEST.fields_by_name['database_name']._options = None
_LISTDATABASESREQUEST.fields_by_name['cluster_id']._options = None
_LISTDATABASESREQUEST.fields_by_name['page_size']._options = None
_LISTDATABASESREQUEST.fields_by_name['page_token']._options = None
_CREATEDATABASEREQUEST.fields_by_name['cluster_id']._options = None
_CREATEDATABASEREQUEST.fields_by_name['database_spec']._options = None
_UPDATEDATABASEREQUEST.fields_by_name['cluster_id']._options = None
_UPDATEDATABASEREQUEST.fields_by_name['database_name']._options = None
_UPDATEDATABASEREQUEST.fields_by_name['new_database_name']._options = None
_DELETEDATABASEREQUEST.fields_by_name['cluster_id']._options = None
_DELETEDATABASEREQUEST.fields_by_name['database_name']._options = None

_DATABASESERVICE = _descriptor.ServiceDescriptor(
  name='DatabaseService',
  full_name='yandex.cloud.mdb.postgresql.v1.DatabaseService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1479,
  serialized_end=2521,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.mdb.postgresql.v1.DatabaseService.Get',
    index=0,
    containing_service=None,
    input_type=_GETDATABASEREQUEST,
    output_type=yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_database__pb2._DATABASE,
    serialized_options=b'\202\323\344\223\002H\022F/managed-postgresql/v1/clusters/{cluster_id}/databases/{database_name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.mdb.postgresql.v1.DatabaseService.List',
    index=1,
    containing_service=None,
    input_type=_LISTDATABASESREQUEST,
    output_type=_LISTDATABASESRESPONSE,
    serialized_options=b'\202\323\344\223\0028\0226/managed-postgresql/v1/clusters/{cluster_id}/databases',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.mdb.postgresql.v1.DatabaseService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEDATABASEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002;\"6/managed-postgresql/v1/clusters/{cluster_id}/databases:\001*\262\322*\"\n\026CreateDatabaseMetadata\022\010Database',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.mdb.postgresql.v1.DatabaseService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEDATABASEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002K2F/managed-postgresql/v1/clusters/{cluster_id}/databases/{database_name}:\001*\262\322*\"\n\026UpdateDatabaseMetadata\022\010Database',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.mdb.postgresql.v1.DatabaseService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEDATABASEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002H*F/managed-postgresql/v1/clusters/{cluster_id}/databases/{database_name}\262\322*/\n\026DeleteDatabaseMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATABASESERVICE)

DESCRIPTOR.services_by_name['DatabaseService'] = _DATABASESERVICE

# @@protoc_insertion_point(module_scope)
